import OFS
from AccessControl import ClassSecurityInfo
from Globals import InitializeClass
import os, urllib
from DateTime import DateTime
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFCore.PortalContent import PortalContent
		
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
import Bar
from Products.CMFCore.WorkflowCore import WorkflowAction

# Import permission names
from Products.CMFCore import CMFCorePermissions
import WhoZnextPermissions

# Factory type information -- makes Events objects play nicely
# with the Types Tool (portal_types)
factory_type_information = (
	{ 'id': 'WhoZnext',
	  'content_icon':'foo.gif',
	  'meta_type': 'WhoZnext',
	  'description': ('WhoZnext is used to find your position on a wait list'),
	  'product':'WhoZnext',
	  'factory': 'manage_addWhoZnext',
	  'immediate_view': 'WhoZnext_edit',
	  'actions':({'id':'view',
				 'name': 'View',
				 'action':'WhoZnext_view',
				 'permissions': (CMFCorePermissions.View,)},
				{'id': 'edit',
				 'name': 'Edit',
				 'action': 'WhoZnext_edit',
				 'permissions': (WhoZnextPermissions.ChangeWhoZnexts,)},
	  ),						# End Actions
	},
	)




# The self parameter of the factory method is the parent folder.
manage_addWhoZnextForm = PageTemplateFile("www/WhoZnext_add", globals())
def manage_addWhoZnext(self
				  , id
				  , title=''
				  , REQUEST=None):
	"Create a WhoZnext and add it to its parent's folder."

	catalogus = WhoZnext(id, title)
	self._setObject(id,catalogus)
	
	
	if REQUEST is not None:
		afterCreate(self.this().getOb(id))

# You may want to inherit from more objects to get more functionality.
# Look at lib/python/OFS/Folder.py and inherit from the same objects 
# like Folder does.
class WhoZnext(PortalContent, DefaultDublinCoreImpl):
	"""
	An object that can display your position on a waitlist.
	"""
	meta_type= 'WhoZnext'
	effective_date = expiration_date = None
	_isDiscussable = 1
	# Declarative security
	security = ClassSecurityInfo()
	security.declareObjectProtected(CMFCorePermissions.View)
	
	def __init__(self
				 ,id
				 ,title= ''):
		DefaultDublinCoreImpl.__init__(self)
		self.id = id
		self.setTitle(title)
	
	security.declareProtected(WhoZnextPermissions.ChangeWhoZnexts, 'edit')
	def manage_editProperties(self,title,REQUEST=None):
		"Edit WhoZnext properties"
		self.title = title

		if REQUEST is not None:
			return Globals.MessageDialog(
				title='Saved',
				message='Changes to <strong>%s</strong> were saved.' % self.id,
				action='manage_main',
				)
	security.declareProtected(WhoZnextPermissions.ChangeWhoZnexts, 'add bar')
	def addBar(self,REQUEST):
		"Adds a cursus to a catalogus"
		Bar.manage_addBarForm(REQUEST)

	addWhoZnextForm = manage_addWhoZnextForm
	addBarForm = Bar.manage_addBarForm

	security.declareProtected(WhoZnextPermissions.ChangeWhoZnexts, 'all meta types')	
	def all_meta_types(self):
		"""
		Return all meta types addable to this catalog. The ZMI uses
		this method (originally defined in ObjectManager) to populate
		the list of classes in the "Add object" menu.
		"""

		# return tuple of dictionaries
		return ( {'name':'WhoZnext',
			 'action':'manage_addProduct/WhoZnext/addWhoZnextForm'},
				 { 'name':'Bar',
			 'action':'manage_addProduct/WhoZnext/addBarForm'})

# Intialize the Event class, setting up security.
InitializeClass(WhoZnext)
